Name:		inspircd
Version:	2.0.20
Release:	3%{?dist}
Summary:	A modular Internet Relay Chat server written in C++

Group:		Applications/Communications
License:	GPLv2
URL:		http://www.%{name}.org/
Source0:	https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz
Source1:    inspircd.service
Source2:    inspircd.conf
Source3:    inspircd.motd
Source4:    inspircd.rules

Patch0:		inspircd-2.0.20-tmpnam.patch

BuildRequires:	make, tar, gcc-c++
BuildRequires:	perl perl-Getopt-Long
# For default modules
BuildRequires:	openssl-devel, mariadb-devel, postgresql-devel, tre-devel
BuildRequires:	sqlite-devel, geoip-devel, openldap-devel
Requires:	perl, openssl, mariadb-libs, postgresql, tre
Requires:	systemd, sqlite, geoip, openldap, openssl

%description
InspIRCd is a project created to provide a stable IRCd which provides a
vast number of features in a modularized form. By keeping the
functionality of the main core to a minimum, yet providing a highly
featured module API, we hope to increase the stability and speed of our
project and make it customizable to the needs of many users. InspIRCd is
released to the public domain under GPL so that you may benefit from our
work. The project is written from scratch, avoiding the inherent
instability and security problems found in many other more "heavyweight"
IRCd distributions.

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
useradd -r -g %{name} -d %{_libdir}/%{name}/ -s /sbin/nologin -c \
"InspIRCd service user" %{name}
exit 0

%prep
%setup -q
%patch0 -p0


%build
./configure --enable-extras=m_ldapauth.cpp,m_ldapoper.cpp,m_mysql.cpp,m_pgsql.cpp,\
m_regex_pcre.cpp,m_regex_posix.cpp,m_regex_tre.cpp,\
m_sqlite3.cpp,m_geoip.cpp,m_ssl_openssl.cpp

%configure --disable-interactive \
    --enable-openssl \
    --prefix=%{_libdir}/%{name} \
    --config-dir=%{_sysconfdir}/%{name} \
    --module-dir=%{_libdir}/%{name}/modules \
    --binary-dir=%{_sbindir}

make %{?_smp_mflags}


%install
%make_install

# systemd service
install -pD -m0644 %{SOURCE1} %{buildroot}%{_unitdir}/inspircd.service

# default config files
install -pD -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -pD -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/%{name}.motd
install -pD -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/%{name}.rules

# Log directory
mkdir -p %{buildroot}%{_libdir}/%{name}/logs

%post
%systemd_post inspircd.service

%preun
%systemd_preun inspircd.service

%postun
%systemd_postun_with_restart inspircd.service

%files
%{_sysconfdir}/%{name}/examples/*
%config(noreplace) %attr(664,inspircd,inspircd) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %attr(664,inspircd,inspircd) %{_sysconfdir}/%{name}/%{name}.motd
%config(noreplace) %attr(664,inspircd,inspircd) %{_sysconfdir}/%{name}/%{name}.rules

%{_libdir}/%{name}
%{_sbindir}/%{name}

%{_unitdir}/%{name}.service

%doc docs README.md
%attr(775, inspircd, inspircd) %{_libdir}/%{name}/logs

%changelog
* Thu Oct 22 2015 Richard Bradfield <bradfirj@fstab.me> - 2.0.20-3
- Adds explicit dependency on perl-Getopt-Long (for rawhide and beyond).

* Wed Jul 22 2015 Richard Bradfield <bradfirj@fstab.me> - 2.0.20-2
- Replaces obsolete tmpnam() call in buildscripts, enables building in Rawhide
  and beyond

* Tue Jul 21 2015 Richard Bradfield <bradfirj@fstab.me> - 2.0.20-1
- Initial package for Copr testing
